pub enum DynamicCircuit {
}Expand description
A dynamic circuit that encapsulates circuits of different qubit counts
Wraps the const-generic quantrs2_circuit::builder::Circuit types behind an
enum so circuits of different sizes can be handled at runtime without heap
allocation overhead.
Examples
use quantrs2_sim::dynamic::DynamicCircuit;
use quantrs2_core::gate::functions::single::Hadamard;
use quantrs2_core::qubit::QubitId;
// Create a 2-qubit circuit dynamically
let mut dc = DynamicCircuit::new(2).expect("2 qubits supported");
assert_eq!(dc.num_qubits(), 2);
// Apply a Hadamard gate
let q0 = QubitId::new(0);
dc.apply_gate(Hadamard { target: q0 }).expect("H gate applied");
assert_eq!(dc.gates().len(), 1);Variants
Q2(Circuit<2>)
2-qubit circuit
Q3(Circuit<3>)
3-qubit circuit
Q4(Circuit<4>)
4-qubit circuit
Q5(Circuit<5>)
5-qubit circuit
Q6(Circuit<6>)
6-qubit circuit
Q7(Circuit<7>)
7-qubit circuit
Q8(Circuit<8>)
8-qubit circuit
Q9(Circuit<9>)
9-qubit circuit
Q10(Circuit<10>)
10-qubit circuit
Q12(Circuit<12>)
12-qubit circuit
Q16(Circuit<16>)
16-qubit circuit
Q20(Circuit<20>)
20-qubit circuit
Q24(Circuit<24>)
24-qubit circuit
Q32(Circuit<32>)
32-qubit circuit
Implementations
Sourceimpl DynamicCircuit
impl DynamicCircuit
Sourcepub fn new(n_qubits: usize) -> QuantRS2Result<Self>
pub fn new(n_qubits: usize) -> QuantRS2Result<Self>
Create a new dynamic circuit with the specified number of qubits
Sourcepub const fn num_qubits(&self) -> usize
pub const fn num_qubits(&self) -> usize
Get the number of qubits in the circuit
Sourcepub fn get_gate_names(&self) -> Vec<String>
pub fn get_gate_names(&self) -> Vec<String>
Get the gate names in the circuit
Sourcepub fn apply_gate<G: GateOp + Clone + Send + Sync + 'static>(
&mut self,
gate: G,
) -> QuantRS2Result<()>
pub fn apply_gate<G: GateOp + Clone + Send + Sync + 'static>( &mut self, gate: G, ) -> QuantRS2Result<()>
Apply a gate to the circuit
Sourcepub fn run(
&self,
simulator: &StateVectorSimulator,
) -> QuantRS2Result<DynamicResult>
pub fn run( &self, simulator: &StateVectorSimulator, ) -> QuantRS2Result<DynamicResult>
Run the circuit on a CPU simulator
Sourcepub const fn is_gpu_available() -> bool
pub const fn is_gpu_available() -> bool
Check if GPU acceleration is available (stub for macOS)
Sourcepub fn run_gpu(&self) -> QuantRS2Result<DynamicResult>
pub fn run_gpu(&self) -> QuantRS2Result<DynamicResult>
Run the circuit on a GPU simulator (stub for macOS)
Sourcepub fn run_best(&self) -> QuantRS2Result<DynamicResult>
pub fn run_best(&self) -> QuantRS2Result<DynamicResult>
Run the circuit on the best available simulator (CPU only if GPU feature is disabled)