pub enum DeviceError {
UnknownGate(String),
UnknownWire(usize),
WrongQubitCount {
gate: String,
expected: usize,
actual: usize,
},
WrongParamCount {
gate: String,
expected: usize,
actual: usize,
},
UnsupportedQubitCount(usize),
SimulationFailed(String),
JsonError(String),
}Expand description
Errors that can occur in the PennyLane device backend.
Variants
UnknownGate(String)
A gate name is not supported by this device
UnknownWire(usize)
A wire index has no mapping to a qubit
WrongQubitCount
Wrong number of qubit arguments for a gate
WrongParamCount
Wrong number of parameter arguments for a gate
UnsupportedQubitCount(usize)
The circuit qubit count is not supported by the simulator
SimulationFailed(String)
Simulation failed with an error message
JsonError(String)
JSON serialization/deserialization error