pub struct QuantRS2Device { /* private fields */ }Expand description
The QuantRS2 PennyLane device backend.
Use QuantRS2Device::execute to run a PennyLane circuit description
(in JSON or as a PennyLaneCircuit struct) and get a PennyLaneResult.
Implementations
Sourceimpl QuantRS2Device
impl QuantRS2Device
Sourcepub fn with_simulator(simulator: StateVectorSimulator) -> Self
pub fn with_simulator(simulator: StateVectorSimulator) -> Self
Create a new device with a custom simulator configuration.
Sourcepub fn execute(
&self,
circuit: &PennyLaneCircuit,
) -> Result<PennyLaneResult, DeviceError>
pub fn execute( &self, circuit: &PennyLaneCircuit, ) -> Result<PennyLaneResult, DeviceError>
Execute a PennyLaneCircuit and return a PennyLaneResult.
Errors
Returns DeviceError if any gate is unsupported, the qubit count is
not supported by the simulator, or the underlying simulation fails.
Sourcepub fn execute_json(&self, json_input: &str) -> Result<String, DeviceError>
pub fn execute_json(&self, json_input: &str) -> Result<String, DeviceError>
Execute a circuit from a JSON string and return a JSON result string.
Errors
Returns DeviceError if JSON deserialization fails, or if the execution
fails.