Auto-generated module
🤖 Generated with SplitRS
Functions
- average_
gate_ fidelity - Calculate the average gate fidelity of a noisy quantum channel.
- concurrence
- Calculate the concurrence of a two-qubit state.
- diamond_
norm_ distance - Estimate the diamond norm distance between two channels.
- entanglement_
of_ formation - Calculate the entanglement of formation for a two-qubit state.
- gate_
error - Calculate the gate error (infidelity) of a quantum channel.
- logarithmic_
negativity - Calculate the logarithmic negativity.
- mutual_
information - Calculate the quantum mutual information of a bipartite state.
- negativity
- Calculate the negativity of a bipartite state.
- partial_
trace - Compute the partial trace of a bipartite density matrix.
- process_
fidelity - Calculate the process fidelity between a quantum channel and a target.
- purity
- Calculate the purity of a quantum state.
- state_
fidelity - Compute the state fidelity between two quantum states.
- unitarity
- Calculate the unitarity of a quantum channel.
- von_
neumann_ entropy - Calculate the von Neumann entropy of a quantum state.