pub struct FredkinSpecialized {
pub control: QubitId,
pub target1: QubitId,
pub target2: QubitId,
}Expand description
Specialized Fredkin (CSWAP) gate
Fields
control: QubitIdtarget1: QubitIdtarget2: QubitIdTrait Implementations
Sourceimpl Clone for FredkinSpecialized
impl Clone for FredkinSpecialized
Sourcefn clone(&self) -> FredkinSpecialized
fn clone(&self) -> FredkinSpecialized
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for FredkinSpecialized
Sourceimpl Debug for FredkinSpecialized
impl Debug for FredkinSpecialized
Sourceimpl GateOp for FredkinSpecialized
impl GateOp for FredkinSpecialized
Sourcefn matrix(&self) -> QuantRS2Result<Vec<Complex64>>
fn matrix(&self) -> QuantRS2Result<Vec<Complex64>>
Returns the matrix representation of this gate
Sourcefn clone_gate(&self) -> Box<dyn GateOp>
fn clone_gate(&self) -> Box<dyn GateOp>
Clone the gate into a new boxed instance
Sourcefn num_qubits(&self) -> usize
fn num_qubits(&self) -> usize
Returns the number of qubits this gate acts on
Sourcefn is_parameterized(&self) -> bool
fn is_parameterized(&self) -> bool
Returns true if this gate is parameterized
Sourceimpl SpecializedGate for FredkinSpecialized
impl SpecializedGate for FredkinSpecialized
Sourcefn apply_specialized(
&self,
state: &mut [Complex64],
n_qubits: usize,
parallel: bool,
) -> QuantRS2Result<()>
fn apply_specialized( &self, state: &mut [Complex64], n_qubits: usize, parallel: bool, ) -> QuantRS2Result<()>
Apply the gate directly to a state vector (optimized implementation)
Sourcefn can_fuse_with(&self, other: &dyn SpecializedGate) -> bool
fn can_fuse_with(&self, other: &dyn SpecializedGate) -> bool
Check if this gate can be fused with another gate
Sourcefn fuse_with(
&self,
other: &dyn SpecializedGate,
) -> Option<Box<dyn SpecializedGate>>
fn fuse_with( &self, other: &dyn SpecializedGate, ) -> Option<Box<dyn SpecializedGate>>
Fuse this gate with another gate if possible