Module contraction

Module contraction 

Contraction strategies for tensor networks

This module provides algorithms and interfaces for contracting tensor networks efficiently.

Structs

ContractionPath
A contraction path for a tensor network

Traits

ContractableNetwork
Trait for a network of tensors that can be contracted

Functions

calculate_greedy_contraction_path
Calculate the optimal contraction path for a tensor network
calculate_optimal_contraction_path
Calculate the optimal contraction path using a more advanced algorithm
contract_network_along_path
Contract a tensor network according to a given contraction path