Module tensor

Module tensor 

Tensor representation for quantum states and operations

This module provides a tensor-based representation for quantum states and operations used in the tensor network simulator.

Structs

Tensor
A tensor representing a quantum state or operation
TensorIndex
A reference to a specific tensor and one of its indices