Module functions

Module functions 

Auto-generated module

🤖 Generated with SplitRS

Functions

average_gate_fidelity
Calculate the average gate fidelity of a noisy quantum channel.
concurrence
Calculate the concurrence of a two-qubit state.
diamond_norm_distance
Estimate the diamond norm distance between two channels.
entanglement_of_formation
Calculate the entanglement of formation for a two-qubit state.
gate_error
Calculate the gate error (infidelity) of a quantum channel.
logarithmic_negativity
Calculate the logarithmic negativity.
mutual_information
Calculate the quantum mutual information of a bipartite state.
negativity
Calculate the negativity of a bipartite state.
partial_trace
Compute the partial trace of a bipartite density matrix.
process_fidelity
Calculate the process fidelity between a quantum channel and a target.
purity
Calculate the purity of a quantum state.
state_fidelity
Compute the state fidelity between two quantum states.
unitarity
Calculate the unitarity of a quantum channel.
von_neumann_entropy
Calculate the von Neumann entropy of a quantum state.