Contraction strategies for tensor networks
This module provides algorithms and interfaces for contracting tensor networks efficiently.
Structs
- Contraction
Path - A contraction path for a tensor network
Traits
- Contractable
Network - Trait for a network of tensors that can be contracted
Functions
- calculate_
greedy_ contraction_ path - Calculate the optimal contraction path for a tensor network
- calculate_
optimal_ contraction_ path - Calculate the optimal contraction path using a more advanced algorithm
- contract_
network_ along_ path - Contract a tensor network according to a given contraction path